@@ -1,8 +1,10 @@
 package CPANPLUS::Dist::Slackware::Plugin::Alien::wxWidgets;
-$CPANPLUS::Dist::Slackware::Plugin::Alien::wxWidgets::VERSION = '1.018';
+
 use strict;
 use warnings;
 
+our $VERSION = '1.019';
+
 sub available {
     my ( $plugin, $dist ) = @_;
     return ( $dist->parent->package_name eq 'Alien-wxWidgets' );
@@ -33,7 +35,7 @@ CPANPLUS::Dist::Slackware::Plugin::Alien::wxWidgets - Configure Alien::wxWidgets
 
 =head1 VERSION
 
-version 1.018
+This document describes CPANPLUS::Dist::Slackware::Plugin::Alien::wxWidgets version 1.019.
 
 =head1 SYNOPSIS
 
@@ -94,11 +96,11 @@ None known.
 
 =head1 SEE ALSO
 
-C<CPANPLUS::Dist::Slackware>
+CPANPLUS::Dist::Slackware
 
 =head1 AUTHOR
 
-Andreas Voegele  C<< <voegelas@cpan.org> >>
+Andreas Voegele E<lt>voegelas@cpan.orgE<gt>
 
 =head1 BUGS AND LIMITATIONS
 
@@ -107,7 +109,7 @@ through the web interface at L<http://rt.cpan.org/>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012, 2013, 2014 Andreas Voegele
+Copyright 2012-2014 Andreas Voegele
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
