@@ -1,8 +1,10 @@
 package CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin;
-$CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin::VERSION = '1.018';
+
 use strict;
 use warnings;
 
+our $VERSION = '1.019';
+
 use File::Spec qw();
 
 sub available {
@@ -199,7 +201,7 @@ CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin - Add an init script and d
 
 =head1 VERSION
 
-version 1.018
+This document describes CPANPLUS::Dist::Slackware::Plugin::Mail::SpamAssassin version 1.019.
 
 =head1 SYNOPSIS
 
@@ -235,21 +237,21 @@ None.
 
 =head1 DEPENDENCIES
 
-Requires the module C<File::Spec> and the command C<cp>.
+Requires the module File::Spec and the command C<cp>.
 
 =head1 INCOMPATIBILITIES
 
-SpamAssassin packages created with C<CPANPLUS::Dist::Slackware> conflict with
+SpamAssassin packages created with CPANPLUS::Dist::Slackware conflict with
 packages created with the SpamAssassin build script available at
 L<http://slackbuilds.org/>.
 
 =head1 SEE ALSO
 
-C<CPANPLUS::Dist::Slackware>
+CPANPLUS::Dist::Slackware
 
 =head1 AUTHOR
 
-Andreas Voegele  C<< <voegelas@cpan.org> >>
+Andreas Voegele E<lt>voegelas@cpan.orgE<gt>
 
 =head1 BUGS AND LIMITATIONS
 
@@ -258,7 +260,7 @@ through the web interface at L<http://rt.cpan.org/>.
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2012, 2013 Andreas Voegele
+Copyright 2012-2014 Andreas Voegele
 
 This library is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
